==> seedsui-react-5.8.81.tgz: package/lib/Transfer/Modal/index.js <==
var _excluded = ["value", "list"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef } from 'react';
import formatValue from "./formatValue";
import Main from "./../Main";

// 内库使用
import ModalPicker from "./../../Modal/MainPicker";

// 测试使用
// import { Modal } from 'seedsui-react'
// const ModalPicker = Modal.MainPicker

// Modal
var Modal = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var value = _ref.value,
    list = _ref.list,
    props = _objectWithoutProperties(_ref, _excluded);
  // 扩展非标准属性
  if (!props.MainProps) {
    props.MainProps = {};
  }
  if (list) props.MainProps.list = list;
  return /*#__PURE__*/React.createElement(ModalPicker, _extends({
    ref: ref
  }, props, {
    className: "transfer-modal".concat(props.className ? ' ' + props.className : ''),
    value: formatValue(value),
    MainComponent: Main
  }));
});
export default Modal;

==> seedsui-react-5.8.90.tgz: package/lib/Transfer/Modal/index.js <==
var _excluded = ["value", "list"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef } from 'react';
import formatValue from "./formatValue";
import Main from "./../Main";

// 内库使用
import ModalPicker from "./../../Modal/MainPicker";

// 测试使用
// import { Modal } from 'seedsui-react'
// const ModalPicker = Modal.MainPicker

// Modal
var Modal = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var value = _ref.value,
    list = _ref.list,
    props = _objectWithoutProperties(_ref, _excluded);
  // 扩展非标准属性
  if (!props.MainProps) {
    props.MainProps = {};
  }
  if (list) props.MainProps.list = list;
  return /*#__PURE__*/React.createElement(ModalPicker, _extends({
    ref: ref
  }, props, {
    MainComponent: (props === null || props === void 0 ? void 0 : props.MainComponent) || Main,
    className: "transfer-modal".concat(props.className ? ' ' + props.className : ''),
    value: formatValue(value)
  }));
});
export default Modal;
